@@ -14,15 +14,14 @@ rdflib_logger = logging.getLogger('rdflib')
 rdflib_logger.setLevel(logging.ERROR)
 
 from rdflib import Graph, logger as rdflib_logger
-from rdflib.plugins.parsers.pyRdfa import pyRdfa as PyRdfa, Options, logger as pyrdfa_logger
-from rdflib.plugins.parsers.pyRdfa.initialcontext import initial_context
+from pyRdfa import pyRdfa as PyRdfa, Options
+from pyRdfa.initialcontext import initial_context
 
 from extruct.utils import parse_xmldom_html
 
 
-# silence rdflib/PyRdfa INFO logs
+# silence rdflib INFO logs
 rdflib_logger.setLevel(logging.ERROR)
-pyrdfa_logger.setLevel(logging.ERROR)
 
 initial_context["http://www.w3.org/2011/rdfa-context/rdfa-1.1"].ns.update({
     "twitter": "https://dev.twitter.com/cards#",
@@ -152,7 +151,11 @@ class RDFaExtractor(object):
                           refresh_vocab_cache=False,
                           check_lite=False)
         g = PyRdfa(options, base=base_url).graph_from_DOM(document, graph=Graph(), pgraph=Graph())
-        jsonld_string = g.serialize(format='json-ld', auto_compact=not expanded).decode('utf-8')
+        jsonld_string = g.serialize(format='json-ld', auto_compact=not expanded)
+
+        # rdflib may return either bytes or strings
+        if isinstance(jsonld_string, bytes):
+            jsonld_string = jsonld_string.decode('utf-8')
         
         try:
             # hack to fix the ordering of multi-value properties (see issue 116)
